@@ -10,7 +10,11 @@ try:
     from apispec.ext.marshmallow import openapi
     from apispec import APISpec as BaseAPISpec
 
-    openapi_converter = openapi.OpenAPIConverter(openapi_version='2.0')
+    openapi_converter = openapi.OpenAPIConverter(
+        openapi_version='2.0',
+        schema_name_resolver=lambda x: None,
+        spec=None
+    )
     schema2jsonschema = openapi_converter.schema2jsonschema
     schema2parameters = openapi_converter.schema2parameters
 except ImportError:
